# Global_Module_For-MHIF
Some static module for mhif, because i am lazy to copy these files

⚠️ Attention！
📦 PyPI 名字（mlgb-hmif）只是安装包标识
📁 模块名（mlgb）由源码目录决定

## 更新教程：
1. 先改版本号
2. rm -rf build dist mlgb_hmif.egg-info
3. python -m build
4. python -m twine upload dist/*
5. pip install -U mlgb-hmif